@@ -57,6 +57,11 @@ def load_data(path):
     directory_listing = [
         os.path.join(path, directory) for directory in os.listdir(path)
     ]
+    directory_listing = list(
+        filter(
+            lambda x: not re.findall(r"[CSV DATA | PLOT DATA]", x), directory_listing
+        )
+    )
     for directory in directory_listing:
         """
         Example:
@@ -209,7 +214,7 @@ if __name__ == "__main__":
             try:
                 raw_dta = load_data(parsed_args.data)
                 write_and_plot(sample_dict=raw_dta)
-            except TypeError as e :
+            except TypeError as e:
                 log.debug(f"{e}")
     else:
         log.debug(f"Doesn't look like you entered a proper directory: {parsed_args}")
